# Checklist

- [ ] [added release note entry](https://pyquations.com/development_guide/release_notes.html#what-to-include) to the `docs/release_notes/vX.X.X.rst` file
- [ ] [imported new packages/modules](https://pyquations.com/development_guide/project_structure.html#organizing-imports) into `pyquations/__init__.py` and the `pyquations/{package}/__init__.py` file and included them in the `__all__` list
- [ ] [locally built the documentation](https://pyquations.com/development_guide/documentation.html#building-the-documentation-locally) and verified that it renders correctly
- [ ] followed all other requirements outlined in the [development guide](https://pyquations.com/development_guide/index.html)

## Issues

closes #xxx (replace xxx with issue number)
